@@ -1,10 +1,19 @@
 from collections import Counter
 
 
-class work_ones(object):
+class work_dy(object):
 
-    def __init__(self, world):
-        self.world = world
+    def __init__(self, *world):
+        self.world = world[0]
+        self.world2 = world[1]
+
+    def merge(self):  # Объединяем два словаря
+        dic3 = self.world2.copy()
+        dic3.update(self.world)
+        return dic3
+
+    def chunk(self):  # Разбиение на фрагменты
+        return [self.world[i:i + int(self.world2)] for i in range(0, len(self.world), int(self.world2))]
 
     def get_vowels(self):  # Получаем гласные
         return [each for each in self.world if each in "aeiou"]
@@ -26,3 +35,5 @@ class work_ones(object):
 
     def palindrome(self):  # Проверка палиндромов
         return self.world == self.world[::-1]
+
+
