@@ -1,9 +1,7 @@
-from .Gaussiandistribution import work_ones
-from .Generaldistribution import work_two
+from .Gaussiandistribution import work_dy
 
 
 def helps():  # поддержка
-    print("'work_ones' :'")
     print('get_vowels - Получаем гласные')
     print('capitalize - Первая буква в верхнем регистре')
     print('check_duplicate - Проверка дубликатов ')
@@ -11,6 +9,5 @@ def helps():  # поддержка
     print('ByteSize - Размер в байтах ')
     print('anagrams - Анаграммы ')
     print('palindrome - Проверка палиндромов ')
-    print("'work_two' :'")
     print('chunk - Разбиение на фрагменты ')
     print('merge - Объединяем два словаря ')
